@@ -51,7 +51,7 @@ class FlaviusBase:
         elif func == 'delete':
             url = self.delete_url
 
-        return request.Request(url=url, headers=headers)
+        return request.Request(url=url, headers=headers, method='POST')
 
     @staticmethod
     def make_get_parameter():
